extends Node2D

# 30分単位で動かす
const CLOCK_UNIT = 30
# 回転速度
const ROTATE_SPEED = 5
# 最大時間
const MAX_TIME = 12 * 60

var clock_time = 0.0
var next_clock_time = 0.0

onready var clock_hour = $Clock/Hour
onready var clock_minute = $Clock/Minute
onready var label = $Label

func _process(delta: float) -> void:
	clock_time = lerp(clock_time, next_clock_time, ROTATE_SPEED * delta)
	# 分・秒に変換する
	var minute = fmod(clock_time, 60)
	var hour = fmod(clock_time/60, 12)
	# 針の回転角度に変換
	clock_hour.rotation_degrees = 360 * hour / 12
	clock_minute.rotation_degrees = 360 * minute / 60
	
	# デバッグ表示
	label.text = "clock_time: %d"%clock_time
	label.text += "\nnext_time: %d"%next_clock_time
	label.text += "\nhour: %d"%hour
	label.text += "\nminute: %d"%minute
	
	# 計算誤差が出るので時間判定は next_clock_time で行う
	var real_hour = int(next_clock_time/60)
	var real_minute = int(fmod(next_clock_time, 60))
	label.text += "\n%d時%d分"%[real_hour, real_minute]

# 時間を増やす
func _on_ButtonRight_pressed() -> void:
	next_clock_time += CLOCK_UNIT
	if next_clock_time >= MAX_TIME:
		# 最大時間を超えたら折返し
		clock_time -= MAX_TIME
		next_clock_time -= MAX_TIME

# 時間を減らす
func _on_ButtonLeft_pressed() -> void:
	next_clock_time -= CLOCK_UNIT
	if next_clock_time < 0:
		# マイナスになったら折返し
		clock_time += MAX_TIME
		next_clock_time += MAX_TIME
